@@ -21,7 +21,11 @@ from polars._utils.deprecation import (
     issue_deprecation_warning,
 )
 from polars._utils.pycapsule import is_pycapsule, pycapsule_to_frame
-from polars._utils.various import _cast_repr_strings_with_schema, issue_warning
+from polars._utils.various import (
+    _cast_repr_strings_with_schema,
+    issue_warning,
+    qualified_type_name,
+)
 from polars._utils.wrap import wrap_df, wrap_s
 from polars.datatypes import N_INFER_DEFAULT, Categorical, String
 from polars.dependencies import _check_for_pyarrow
@@ -37,10 +41,12 @@ if TYPE_CHECKING:
         ArrowArrayExportable,
         ArrowStreamExportable,
         Orientation,
+        PolarsDataType,
         SchemaDefinition,
         SchemaDict,
     )
     from polars.dependencies import numpy as np
+    from polars.dependencies import torch
     from polars.interchange.protocol import SupportsInterchange
 
 
@@ -358,14 +364,95 @@ def from_numpy(
     """
     return wrap_df(
         numpy_to_pydf(
-            data, schema=schema, orient=orient, schema_overrides=schema_overrides
+            data=data,
+            schema=schema,
+            schema_overrides=schema_overrides,
+            orient=orient,
+        )
+    )
+
+
+def from_torch(
+    tensor: torch.Tensor,
+    schema: SchemaDefinition | None = None,
+    *,
+    schema_overrides: SchemaDict | None = None,
+    orient: Orientation | None = None,
+    force: bool = False,
+) -> DataFrame:
+    """
+    Construct a DataFrame from a PyTorch Tensor.
+
+    Parameters
+    ----------
+    tensor : :class:`torch.Tensor`
+        A PyTorch `Tensor` object of one or more dimensions.
+    schema : Sequence of str, (str,DataType) pairs, or a {str:DataType,} dict
+        The DataFrame schema may be declared in several ways:
+
+        * As a dict of {name:type} pairs; if type is None, it will be auto-inferred.
+        * As a list of column names; in this case types are automatically inferred.
+        * As a list of (name,type) pairs; this is equivalent to the dictionary form.
+
+        If you supply a list of column names that does not match the names in the
+        underlying data, the names given here will overwrite them. The number
+        of names given in the schema should match the underlying data dimensions.
+    schema_overrides : dict, default None
+        Support type specification or override of one or more columns; note that
+        any dtypes inferred from the columns param will be overridden.
+    orient : {None, 'col', 'row'}
+        Whether to interpret two-dimensional data as columns or as rows. If None,
+        the orientation is inferred by matching the columns and data dimensions. If
+        this does not yield conclusive results, column orientation is used.
+    force : bool
+        If False, the conversion is performed only if the Tensor is on CPU, does not
+        require grad, does not have its conjugate bit set, and is of a dtype (and
+        layout) that NumPy supports; this will typically be zero-copy. If True, it
+        is equivalent to calling `.detach().cpu().resolve_conj().resolve_neg()`
+        before passing the Tensor to Polars.
+
+    Returns
+    -------
+    DataFrame
+
+    Examples
+    --------
+    >>> import torch
+    >>> data = torch.tensor(
+    ...     [
+    ...         [1234.5, 200.0, 3000.5],
+    ...         [8000.0, 500.5, 6000.0],
+    ...     ]
+    ... )
+    >>> df = pl.from_torch(
+    ...     data,
+    ...     schema=["colx", "coly", "colz"],
+    ...     schema_overrides={"colz": pl.Float64},
+    ... )
+    >>> df
+    shape: (2, 3)
+    ┌────────┬───────┬────────┐
+    │ colx   ┆ coly  ┆ colz   │
+    │ ---    ┆ ---   ┆ ---    │
+    │ f32    ┆ f32   ┆ f64    │
+    ╞════════╪═══════╪════════╡
+    │ 1234.5 ┆ 200.0 ┆ 3000.5 │
+    │ 8000.0 ┆ 500.5 ┆ 6000.0 │
+    └────────┴───────┴────────┘
+    """
+    return wrap_df(
+        numpy_to_pydf(
+            data=tensor.numpy(force=force),
+            schema=schema,
+            schema_overrides=schema_overrides,
+            orient=orient,
         )
     )
 
 
 # Note: we cannot @overload the typing (Series vs DataFrame) here, as pyarrow
-# does not implement any support for type hints; attempts to hint here will
-# simply result in mypy inferring "Any", which isn't useful...
+# does not (yet?) implement any support for type hints; attempts to hint here
+# will simply result in mypy inferring "Any", which isn't at all useful...
 
 
 def from_arrow(
@@ -493,7 +580,7 @@ def from_arrow(
             )
         )
 
-    msg = f"expected PyArrow Table, Array, or one or more RecordBatches; got {type(data).__name__!r}"
+    msg = f"expected PyArrow Table, Array, or one or more RecordBatches; got {qualified_type_name(data)!r}"
     raise TypeError(msg)
 
 
@@ -541,7 +628,12 @@ def from_pandas(
     """
     Construct a Polars DataFrame or Series from a pandas DataFrame, Series, or Index.
 
-    This operation clones data.
+    This operation may clone data. If you want to ensure that in-place modifications
+    of the output don't affect the input, you may want to consider one of the following:
+
+    - Enable `Copy-On-Write <https://pandas.pydata.org/docs/dev/user_guide/copy_on_write.html>`_
+      in pandas.
+    - Call :meth:`DataFrame.clone` on the output of `from_pandas`.
 
     This requires that :mod:`pandas` and :mod:`pyarrow` are installed.
 
@@ -616,7 +708,7 @@ def from_pandas(
             )
         )
     else:
-        msg = f"expected pandas DataFrame or Series, got {type(data).__name__!r}"
+        msg = f"expected pandas DataFrame or Series, got {qualified_type_name(data)!r}"
         raise TypeError(msg)
 
 
@@ -625,6 +717,9 @@ def from_repr(data: str) -> DataFrame | Series:
     """
     Construct a Polars DataFrame or Series from its string representation.
 
+    .. versionchanged:: 0.20.17
+        The `tbl` parameter was renamed to `data`.
+
     Parameters
     ----------
     data
@@ -639,7 +734,8 @@ def from_repr(data: str) -> DataFrame | Series:
     wrapped headers are accounted for, and dtypes are automatically identified.
 
     Currently compound/nested dtypes such as List and Struct are not supported;
-    neither are Object dtypes.
+    neither are Object dtypes. The DuckDB table/relation repr is also compatible
+    with this function.
 
     See Also
     --------
@@ -714,24 +810,47 @@ def from_repr(data: str) -> DataFrame | Series:
 def _from_dataframe_repr(m: re.Match[str]) -> DataFrame:
     """Reconstruct a DataFrame from a regex-matched table repr."""
     from polars.datatypes.convert import dtype_short_repr_to_dtype
+    from polars.io.database._inference import dtype_from_database_typename
+
+    def _dtype_from_name(tp: str | None) -> PolarsDataType | None:
+        return (
+            None
+            if tp is None
+            else (
+                dtype_short_repr_to_dtype(tp)
+                or dtype_from_database_typename(tp, raise_unmatched=False)
+            )
+        )
 
     # extract elements from table structure
     lines = m.group().split("\n")[1:-1]
     rows = [
         [re.sub(r"^[\W+]*│", "", elem).strip() for elem in row]
-        for row in [re.split("[┆|]", row.rstrip("│ ")) for row in lines]
+        for row in [re.split("[│┆|]", row.lstrip("#. ").rstrip("│ ")) for row in lines]
         if len(row) > 1 or not re.search("├[╌┼]+┤", row[0])
     ]
 
     # determine beginning/end of the header block
     table_body_start = 2
+    found_header_divider = False
     for idx, (elem, *_) in enumerate(rows):
-        if re.match(r"^\W*╞", elem):
+        if re.match(r"^\W*[╞]", elem):
+            found_header_divider = True
             table_body_start = idx
             break
 
     # handle headers with wrapped column names and determine headers/dtypes
-    header_block = ["".join(h).split("---") for h in zip(*rows[:table_body_start])]
+    header_rows = rows[:table_body_start]
+    header_block: list[Sequence[str]]
+    if (
+        not found_header_divider
+        and len(header_rows) == 2
+        and not any("---" in h for h in header_rows)
+    ):
+        header_block = list(zip(*header_rows))
+    else:
+        header_block = ["".join(h).split("---") for h in zip(*header_rows)]
+
     dtypes: list[str | None]
     if all(len(h) == 1 for h in header_block):
         headers = [h[0] for h in header_block]
@@ -740,6 +859,11 @@ def _from_dataframe_repr(m: re.Match[str]) -> DataFrame:
         headers, dtypes = (list(h) for h in itertools.zip_longest(*header_block))
 
     body = rows[table_body_start + 1 :]
+    if not headers[0] and not dtypes[0]:
+        body = [row[1:] for row in body]
+        headers = headers[1:]
+        dtypes = dtypes[1:]
+
     no_dtypes = all(d is None for d in dtypes)
 
     # transpose rows into columns, detect/omit truncated columns
@@ -754,10 +878,10 @@ def _from_dataframe_repr(m: re.Match[str]) -> DataFrame:
 
     # init cols as String Series, handle "null" -> None, create schema from repr dtype
     data = [
-        pl.Series([(None if v == "null" else v) for v in cd], dtype=String)
+        pl.Series([(None if v in ("null", "NULL") else v) for v in cd], dtype=String)
         for cd in coldata
     ]
-    schema = dict(zip(headers, (dtype_short_repr_to_dtype(d) for d in dtypes)))
+    schema = dict(zip(headers, (_dtype_from_name(d) for d in dtypes)))
     if schema and data and (n_extend_cols := (len(schema) - len(data))) > 0:
         empty_data = [None] * len(data[0])
         data.extend((pl.Series(empty_data, dtype=String)) for _ in range(n_extend_cols))
